package
Version:
v0.0.0-...-d7c879d
Opens a new window with list of versions in this module.
Published: Oct 24, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CreateBstSet(comparator func(thisValue interface{}, compareValue interface{}) int) BstSet
创建二分搜索树实现的集合
func (b BstSet) Add(value interface{})
type Set interface {
fmt.Stringer
Add(value interface{})
Remove(value interface{}) error
Contains(value interface{}) bool
GetSize() int
IsEmpty() bool
}
集合的解耦定义
Source Files
¶
Click to show internal directories.
Click to hide internal directories.